@@ -255,13 +255,13 @@ class ResponseObject(object):
 	def dict(self, serializable=False):
 		dictionary = {}
 		for key, value in self.items():
-			if isinstance(value, object):
-				dictionary[key] = str(value)
-			else:
-				if value == "True": value = True
-				if value == "False": value = False
-				if value == "None": value = None
-				dictionary[key] = value
+			if serializable:
+				if isinstance(value, object):
+					value = str(value)
+				elif value == "True": value = True
+				elif value == "False": value = False
+				elif value == "None": value = None
+			dictionary[key] = value
 		return dictionary
 	# assign self variables by dictionary.
 	def assign(self, dictionary):
@@ -293,7 +293,7 @@ class ResponseObject(object):
 		else:
 			return json.dumps(self.dict(), indent=4)
 	def json(self,):
-		return self.dictionary(serializable=True)
+		return json.dumps(self.dictionary(serializable=True), indent=4)
 		return json.dumps(self)
 		return json.dumps(self, default=lambda o: o.__dict__)
 	#def __dict__(self):
